/**
 * @file Gui/panel.h
 * @brief Version information for eVaf modules
 * @author Enar Vaikene
 *
 * Copyright (c) 2011-2019 Enar Vaikene
 *
 * This file is part of the eVaf C++ cross-platform application development framework.
 *
 * This file can be used under the terms of the GNU General Public License
 * version 3.0 as published by the Free Software Foundation and appearing in
 * the file LICENSE included in the packaging of this file. Please review the
 * the following information to ensure the GNU General Public License version
 * 3.0 requirements will be met: http://www.gnu.org/copyleft/gpl.html.
 *
 * Alternatively, this file may be used in accordance with the Commercial License
 * Agreement provided with the Software.
 */

#ifndef __GUI_PANEL_H
#  define __GUI_PANEL_H

#include "libgui.h"

#include <QWidget>

namespace eVaf {

/**
 * Common eVaf GUI library.
 *
 * This library contains common Graphical User Interface functions and classes for eVaf applications.
 * This library is a required dependency for all the eVaf modules that implement elements of the GUI.
 */
namespace Gui {

/**
 * eVaf GUI panel class.
 * @code#include <Gui/Panel>@endcode
 *
 * The Gui::Panel class is the generic widget for eVaf GUI applications. It is an empty
 * widget that can be filled with actual user interface elements like labels, edit boxes etc.
 * Gui::Panel acts like a normal widget, which can be shown as a stand-alone window or added to other
 * user interface layouts.
 *
 * The main purpose of Gui::Panel is that it can be added to one of the eVaf document interface
 * managers.
 */
class GUI_EXPORT Panel : public QWidget
{
    Q_OBJECT

public:

    Panel(QWidget * parent = nullptr, Qt::WindowFlags f = Qt::WindowFlags());

    virtual ~Panel();

};

} // namespace eVaf::Gui
} // namespace eVaf


#endif // panel.h
